@@ -1,10 +1,10 @@
-__version__ = "0.1.14"
+__version__ = "0.1.15"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.14)'
+__git_branch__ = '(detached from v0.1.15)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '1cc3f45f08ed1f0c48c3378274694b65ebb70581'
-__git_head_subject__ = 'Finished release v0.1.14.'
+__git_head_hash__ = 'c2538d066091595d68c8ff0262bde09115378852'
+__git_head_subject__ = 'flake8 fixes'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
